clc
clear all
close all
addpath('xxxx') %% Add path to the wavi toolbox
import wawi.*
omegaGlobal = linspace(0.0001,6.3,1000);
%% INPUT
InputPrefix='Sulafjorden_TD21_S1-G1_'; % Prefix in front of imported filenames 
path='xxxx'; % Add path to input/result folder
%% Aerodynamic properties girder (element type 1)
D(:,:,1) = 2.5; % Height of element type 1 (girder)
B(:,:,1) = 37.5; % Width of the element type 1 (girder)                           
order = 3; % Order of the polynomial to fit to the data
alpha0 = 0*2*pi/360; % Linearization point
file = strcat(path,'StaticCoefficients',InputPrefix(12:22),'.xls');
sheets = sheetnames(file);
Data = readtable(file,'sheet',sheets(1));
[loadCoeff(:,:,1)] = wawi.wind.linearQuasiSteadyCoeff(Data,order,alpha0); % Input file that defines the aerodynamic static load coefficients for element type 1 (girder) 
admiCoeff(:,:,1) = NaN(6,4);  % Admittance functions (currently not implemented)
load(strcat(path,'AD',InputPrefix(12:22),'.mat'))
vRed = Vred; clear Vred
[p,k1c,k2c] = wawi.wind.fitpoly2kad(vRed,AD,2); % Fit polynomials to experimental data
adFun1 = @(vRed)wawi.wind.adpolyk(vRed,p,k1c,k2c); % Define functon that calculates values of aerodynamic derivatives
%adFun1 = @(vRed)wawi.wind.adquasisteady(vRed,loadCoeff(:,:,1),B(:,:,1),D(:,:,1));
%adFun1 = @(vRed) wawi.wind.adtheodorsen(vRed)
%% Aerodynamic properties of main cable (element type 2)
B(:,:,2) = 0.8;         % Width of element type 2 (cable)
D(:,:,2) = 0.8;         % Height of element type 2 (cable)
loadCoeff(:,:,2) = zeros(6,1); % Initialize the matrix
loadCoeff(1,1,2) = 1.2; % Set the drag coefficient
adFun2 = @(vRed)wawi.wind.adquasisteady(vRed,loadCoeff(:,:,2),B(:,:,2),D(:,:,2)); % Define function that calculates aerodynamic derivatives based on quasi-steady theory
adFuns = {adFun1,adFun2};

%% Load structural props
load(strcat(InputPrefix,'AbaqusResults.mat')')
% Structural damping
zeta = 0.2/100;
[ genMs, genKs ] = wawi.misc.construct_modal_matrices(f, Mg);
wn = 2*pi*f;
for i=1:length(f)
    genCs(i,i)=2*zeta*wn(i)*genMs(i,i);
end
%% Geometry, environmental and computational parameters: wind
xRef = [0 0 0]';    % Position of reference point
z0 = 0;            % the height above ground in the reference point
eV1 = [0 1 0]';             % Direction of mean wind velocity in global coordinates
eV2tmp = -[1 1 0]';        % Vector in the eV1-eV2 plane
eLe2 = [0, 1, 0];
[TG2V] = wawi.misc.transform_unit(eV1, eV2tmp);       % Define the transformation matrix Global 2 local for the Mean wind
rho = 1.25;                                           % Air density
TG2Le0 = wawi.misc.element_transform_matrices(elements, nodes, eLe2);
%% Plot nodes, elements and elementorientation
h1 = figure;
h2 = figure;
wawi.plot.plotwindelements(h1,h2,nodes,elements,TG2Le0,TG2V)
axis square
%% Plot selected modes
figure
sk = 100;
mode = 1;
tmp = max(abs([phi(1:6:end,mode); phi(2:6:end,mode); phi(3:6:end,mode)]));
sk = sk/tmp;
plot3(nodes(:,2),nodes(:,3),nodes(:,4),'o')
hold on
plot3(nodes(:,2)+sk*phi(1:6:end,mode),nodes(:,3)+sk*phi(2:6:end,mode),nodes(:,4)+sk*phi(3:6:end,mode),'o')
axis([-1 1 -1 1 -1 1]*1000)
%% Flutter analysis
dV = 10;
vRef = 40;
stop = 0;
k = 0;
clear s; clear sv; clear psi; clear psiv; clear vRefs;
% SelModes = [1:50];
% SelModes = [1:23];
% SelModes = [4,23];
% SelModes = [5,23];
 SelModes = [4,5,23];
% SelModes = [4,5,12,23];
% SelModes = [4,5,12,21,23]; 
% SelModes = [1,4,5,12,21,23]; 

while stop == 0
    disp('******')
    vRef
    % wind profile - constant
    profile = @(x) vRef;
    tic
    [ genCae, genKae ] = wawi.wind.compute_aero_matrices(omegaGlobal, adFuns, nodes, elements, TG2Le0, TG2V, phi, B, rho, profile);
    toc
    Ktot = wawi.misc.matrixsum(genKs, -genKae); Ctot = wawi.misc.matrixsum(genCs, -genCae); Mtot = wawi.misc.matrixsum(genMs, zeros(size(genCae)));
    [s, psi,nonconvergedModes] = wawi.eig.iteig(Ktot(SelModes, SelModes,:), Ctot(SelModes, SelModes,:), Mtot(SelModes, SelModes,:), omegaGlobal);
    if max(real(s))<0
        k = k+1;
        vRefs(1,k) = vRef; 
        sv(:,k) = s;
        psiv(:,:,k) = psi;
        vRef = vRef + dV;
    else
        vRef = vRef-dV;
        dV = dV/2;
        vRef = vRef+dV ;       
        if dV<0.1
            stop = 1;
        end
    end
end
%% Plot eigenvalues
fig3=figure; hold on; 
subplot(1,2,1); 
plot(vRefs,imag(sv),'LineWidth',1.2); grid on;  
xlabel('$\mathrm{V\:[ms^{-1}]}$','Interpreter','Latex')
ylabel('$\mathrm{\omega\:[rads^{-1}]}$','Interpreter','Latex')
ax = gca; ax.FontSize = 16;
xlim([40 vRefs(end)])
subplot(1,2,2)
plot(vRefs,-real(sv)./abs(sv),'LineWidth',1.2); grid on; 
xlabel('$\mathrm{V\:[ms^{-1}]}$','Interpreter','Latex')
ylabel('$\mathrm{\zeta\:[-]}$','Interpreter','Latex')
ax = gca; ax.FontSize = 16;
lgd=legend('V2', 'V3', 'T1','Location','northwest');
xlim([40 vRefs(end)])
fig3.Position=[680 558 1120 250];
saveas(fig3,strcat('OmegaZeta',InputPrefix(18:end-1),'.jpg'))


[~, criticalMode] = max(real(s)); % Identify critical mode

% Plot Argand diagrams
fig4=figure; 
psi_cr=psi(:,criticalMode);
psi_cr(end+1)=1;
Z=compass(psi_cr);
colors = get(0,'DefaultAxesColorOrder');
for i=1:(length(Z)-1)
set(Z(i),'color',colors(mod(i-1,length(colors))+1,:),'linewidth',1.5)
end  
% lgd=legend('V2', 'V3', 'T1','Location','west');
% lgd.Position=[0.4545 0.2000 0.1268 0.1619];
% lgd.FontSize=16;
ax = ancestor(Z(2),'axes');
th = findall(ax,'Type','Text');
set(th,'FontSize',16)
set(Z(i+1),'LineStyle','none')
%saveas(fig4,strcat('ArgandDiagram_',InputPrefix(18:end-1),'.jpg'))


%%

[~, criticalMode] = max(real(s)); % Identify critical mode

figure
bar(1:size(psi,1),abs(psi(:,criticalMode)))
xlabel('Still-air mode')

% Save to compare with other configurations
psi_temp=psi; 
psi=psi(:,criticalMode);
save([path 'psi1'],'psi')
psi=psi_temp;


%% Animate flutter vibration mode

[~, criticalMode] = max(real(s)); % Identify critical mode

nFrames = 50; % Number of frames per cycle
nCycles = 10;
figure
for k = 1:nFrames*nCycles
    sk = 50*exp(1i*2*pi*k/nFrames);
    mode = 1;
    u = phi(:,SelModes)*psi(:,criticalMode);
    tmp = max(abs([u(1:6:end,mode); u(2:6:end,mode); u(3:6:end,mode)]));
    sk = sk/tmp;
    plot3(nodes(:,2),nodes(:,3),nodes(:,4),'o','MarkerSize',2)
    hold on
    plot3(nodes(:,2)+real(sk*u(1:6:end,1)),nodes(:,3)+real(sk*u(2:6:end,1)),nodes(:,4)+real(sk*u(3:6:end,1)),'o','MarkerSize',2)
    axis([-1 1 -1 1 -1 1]*1500)
    drawnow
    hold off
end

%% K
omegaCrit=imag(sv(criticalMode,end));
KCrit=B(:,:,1)*omegaCrit/vRef



