clear all
close all
clc

path='xxxx'; % Add path to result folder
%% Polynomial fits

D_b=2.5;
rho_b=1.25;
G_b=[5.5 10.5 15.5];
V_cr=[1.055468750000000e+02 1.033593750000000e+02 1.055468750000000e+02;
    1.049218750000000e+02 1.052343750000000e+02 100.546875; 
    87.578125000000000 91.171875000000000 86.015625];
V_N400=75.9*ones(2,1);
%rows=sections, columns=gaps

K=[0.3777 0.4027 0.4228; 
    0.3802 0.4040 0.4156; 
    0.4594 0.4659 0.4827];

fig2=figure; hold on; grid on; grid minor; box on; 
ax = gca;
yyaxis left
plot(G_b/D_b,V_cr(1,:),'--bo', 'MarkerSize',14,'LineWidth',1.2)
plot(G_b/D_b,V_cr(2,:),'--ro', 'MarkerSize',14,'LineWidth',1.2)
plot(G_b/D_b,V_cr(3,:),'--o','color',[0 0.6 0.3], 'MarkerSize',14,'LineWidth',1.2)
ylabel('$\mathrm{V_{cr}\:[ms^{-1}]}$','Interpreter','Latex')
ylim([70 120])
yyaxis right
plot([0;9],V_N400,'color',[1. 0.500 0.0],'LineWidth',1.2)
set(ax,'YTick',75.9)
xlabel('$\mathrm{gap/depth\:[-]}$','Interpreter','Latex')
ylim([70 120])
xlim([0 8.4])
lgd=legend('S1','S2','S3','N400');
lgd.Location='northeast';
ax.FontSize = 16;
xticks([0 2 4 6 8])
get(fig2,'Position')
fig2.Position=[441 437 740 900];
ax.YAxis(1).Color = 'k';
ax.YAxis(2).Color = 'k';
saveas(fig2,'stabilityLimits.jpg')

%% Comparison of modes in historam

li=[1	1	1	1	1	1	1	1	1;
3	2	2	2	2	2	2	2	2;
4	4	3	4	4	3	4	4	3;
5   5   5   5   5   5   5   5   5;
6	6	6	6	6	6	6	6	6;
7	8	12	7	8	12	7	8	12;
12	12	11	12	12	11	12	12	11;
20	22	34	21	23	34	21	28	34;
21	20	20	20	20	20	20	20	19;
23	23	22	23	22	21	23	22	21];
% rows are modes and columns are configurations
fig1=figure; hold on; grid on; box on; 
Defaultcolors = [0 0.4470 0.7410
    0.8500 0.3250 0.0980
    0.9290 0.6940 0.1250
    0.4940 0.1840 0.5560
    0.4660 0.6740 0.1880
    0.3010 0.7450 0.9330
    0.6350 0.0780 0.1840
    0 0 0
    0 0.5000 0.5000];
colororder(Defaultcolors);
n_configs=9;
psi_mod=zeros(size(li,1),n_configs);
for i=1:n_configs
    load(strcat(path,'psi',string(i),'.mat'))
    n=1;
    for n=1:size(li,1)
        j=li(n,i);
        psi_mod(n,i)=psi(j,1);
    end
end
bar(1:size(li,1),abs(psi_mod'))
xlabel('Still-air mode','Interpreter','Latex')
ylabel('$\mathrm{|\eta|}$','Interpreter','Latex')
xticks(1:1:size(li,1))
xticklabels({'H1', 'V1', 'V2', 'V3', 'V4' 'H3', 'V5', 'H4', 'V7', 'T1'})
legend('S1-G1','S1-G2','S1-G3','S2-G1','S2-G2','S2-G3','S3-G1','S3-G2','S3-G3')
ylim([0 1])
fig1.Position=[680 558 1120 500];
ax = gca; ax.FontSize = 16; ax.XGrid = 'off'; 

saveas(fig1,'ComparisonofModes.jpg')

